nagios_host 'manchesterhive.com' do
	options 'use' => 'noping-host-https',
		'alias' => 'MUP',
		'address' => 'www.manchesterhive.com',
		'contact_groups' => 'cs_escalation,mup',
		'notes' => 'Manchester Hive Live Site',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/MUP/pages/174584346/Server+Setup+-+MUP'
end
#------------------------------------------------------------------------------------
# HOMEPAGE
# Checks the homepage of the live manchesterhive site and checks for the string 'Manchester'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'manchesterhive.com-Live Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'manchesterhive.com',
		'display_name' => 'Live Homepage',
		'check_command' => 'https_content_check_basic_auth!mup:mup2017!/!Manchester!10!20!',
		'notes' => 'Manchester Hive Live Site',
		'notes_url' => 'https://wwwmanchesterhive.com/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 1)
# Checks the homepage of the live mup site on the first web node and checks for the string 'Manchester'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'manchesterhive.com-Live Homepage: mup-web-3' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'manchesterhive.com',
		'display_name' => 'Live Homepage: mup-web-3',
		'check_command' => 'https_content_check_basic_auth_single_node!mup:mup2017!/!Manchester!10!20!mup-web-live1!mup-web-3!',
		'contact_groups' => 'admins_email_only,mup',
		'notes' => 'Manchester Hive Live Site: mup-web-3',
		'notes_url' => 'https://manchesterhive.com/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 2)
# Checks the homepage of the live mup site on the second web node and checks for the string 'Manchester'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'manchesterhive.com-Live Homepage: mup-web-4' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'manchesterhive.com',
		'display_name' => 'Live Homepage: mup-web-4',
		'check_command' => 'https_content_check_basic_auth_single_node!mup:mup2017!/!Manchester!10!20!mup-web-live2!mup-web-4!',
		'contact_groups' => 'admins_email_only,mup',
		'notes' => 'Manchester Hive Live Site: mup-web-4',
		'notes_url' => 'https://manchesterhive.com/'
end
#------------------------------------------------------------------------------------
# SEARCH
# Checks the search page of the live mup site and checks for the string 'Browse'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'manchesterhive.com-Live Search' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'manchesterhive.com',
		'display_name' => 'Live Search',
		'check_command' => 'https_content_check_basic_auth!mup:mup2017!/browse?level=parent!Browse!10!20!',
		'notes' => 'Manchester Hive Live Site',
		'notes_url' => 'https://manchesterhive.com/browse?level=parent'
end
#------------------------------------------------------------------------------------
# VIEW
# Checks a content view page of the live mup site for the book at the URL
# /view/9781526130921/9781526130921.xml.  The title of this book is "Writing the war on terrorism".  This check
# looks for the string 'Writing' in the response.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'manchesterhive.com-Live Content View' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'manchesterhive.com',
		'display_name' => 'Live Content View',
		'check_command' => 'https_content_check_basic_auth!mup:mup2017!/view/9781526130921/9781526130921.xml!Writing!10!20!',
		'notes' => 'Manchester Hive Live Site',
		'notes_url' => 'https://manchesterhive.com/view/9781526130921/9781526130921.xml'
end
#------------------------------------------------------------------------------------
# LOADER
# Checks a loader login page and looks for the string 'Login' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'manchesterhive.com-Production Loader' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'manchesterhive.com',
		'display_name' => 'Production Loader',
		'check_command' => 'check_loader_auth!admin.manchesterhive.com!/login!mup:mup2017!"MUP Production Management Portal"!20!10',
		'contact_groups' => 'admins_email_only,mup',
		'notes' => 'Manchester Hive Live Loader',
		'notes_url' => 'https://admin.manchesterhive.com/login'
end
#------------------------------------------------------------------------------------
# STAGING
# Checks the staging site homepage and looks for the string 'Manchester' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'manchesterhive.com-Staging Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'manchesterhive.com',
		'display_name' => 'Staging Homepage',
		'check_command' => 'check_staging_auth!mup.mup-staging.irl.pubfactory.com!mup:mup2017!Manchester!20!10',
		'contact_groups' => 'admins_email_only,mup',
		'notes' => 'Manchester Hive Staging Site',
		'notes_url' => 'https://mup.mup-staging.irl.pubfactory.com/'
end
#------------------------------------------------------------------------------------
# AMX
# Checks the production amx homepage and looks for the string 'Manchester' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'manchesterhive.com-Production AMX' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'manchesterhive.com',
		'display_name' => 'Production AMX',
		'check_command' => 'check_loader_auth!ams.manchesterhive.com!/login!mup:mup2017!AMS!20!10',
		'contact_groups' => 'admins_email_only,mup',
		'notes' => 'Manchester Hive AMX',
		'notes_url' => 'https://ams.manchesterhive.com/login'
end
#------------------------------------------------------------------------------------
# FAIL OPEN
# Checks the production homepage and makes sure we're not in fail open by checking
# that the string "Provisional Account" is NOT in the page.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'manchesterhive.com-Live Site Fail Open' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'manchesterhive.com',
		'display_name' => 'Live Site Fail Open',
		'check_command' => 'http_negate_content_check_basic_auth!www.manchesterhive.com!mup:mup2017!"provisional account"',
		'contact_groups' => 'admins_email_only,mup',
		'notes' => 'Manchester Hive Live Site Failopen',
		'notes_url' => 'https://manchesterhive.com/'
end
